//deploy vm
import { ApolloClient, createHttpLink, gql, InMemoryCache } from '@apollo/client/core'

export const apolloClient = () => {
  const httpLink = createHttpLink({
    uri: import.meta.env.VITE_APP_GRAPHQL_ENDPOINT,
    credentials: 'include' // Include credentials for cross-origin requests
  })

  const apolloClient = new ApolloClient({
    cache: new InMemoryCache(),
    link: httpLink,
    headers: {
      Accept: 'application/json',
      'Accept-Encoding': 'gzip, deflate',
      'Cache-Control': 'no-cache',
      Connection: 'keep-alive',
      'Content-Type': 'application/json'
      // Add other headers as needed
    }
  })
  return apolloClient
}

export const queries = {
  monalisa: {
    gangguan: {
      rekap: {
        dispatchingTimeGangguan: gql`
          query DaftarmonalisaDispatchingTimeGangguan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaDispatchingTimeGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        rekapitulasiEnsGangguan: gql`
          query DaftarmonalisaRekapitulasiEnsGangguan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRekapitulasiEnsGangguan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        gangguanBelumSelesai: gql`
          query DaftarmonalisaGangguanBelumSelesai(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaGangguanBelumSelesai(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              jumlah_gangguan
              jumlah_informasi
              total
            }
          }
        `,
        gangguanPerJenisGangguan: gql`
          query DaftarmonalisaGangguanPerJenisGangguan(
            #$nama_regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaGangguanPerJenisGangguan(
              #nama_regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id_jenis_gangguan
              nama_jenis_gangguan
              jumlah
              persen
            }
          }
        `,
        jumlahDurasiRptRctGangguan: gql`
          query DaftarmonalisaJumlahDurasiRptRctGangguan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahDurasiRptRctGangguan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_durasi_response_time_bulan_ini
              count_durasi_response_time_bulan_ini
              avg_durasi_response_time_bulan_ini
              total_durasi_recovery_time_bulan_ini
              count_durasi_recovery_time_bulan_ini
              avg_durasi_recovery_time_bulan_ini
              total_durasi_response_time_tahun_ini
              count_durasi_response_time_tahun_ini
              avg_durasi_response_time_tahun_ini
              total_durasi_recovery_time_tahun_ini
              count_durasi_recovery_time_tahun_ini
              avg_durasi_recovery_time_tahun_ini
            }
          }
        `,
        jumlahKaliGangguan: gql`
          query DaftarMonalisaJumlahKaliGangguan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahKaliGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_uid
              nama_up3
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        laporUlangGangguan: gql`
          query DaftarmonalisaRekapitulasiLaporUlangGangguan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRekapitulasiLaporUlangGangguan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        recoveryTimeGangguan: gql`
          query DaftarmonalisaRecoveryTimeGangguan(
            #$regional: regional
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRecoveryTimeGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        responseTimeGangguan: gql`
          query DaftarmonalisaResponseTimeGangguan(
            #regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaResponseTimeGangguan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `
      }
    },
    keluhan: {
      rekap: {
        jumlahKaliKeluhan: gql`
          query DaftarMonalisaJumlahKaliKeluhan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahKaliKeluhan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        recoveryTimeKeluhan: gql`
          query DaftarmonalisaRecoveryTimeKeluhan(
            #$regional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRecoveryTimeKeluhan(
              #regional: $regional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `
      }
    },
    laporan: {
      bulanan: {
        penurunanJumlahKomplainBulanan: gql`
          query DaftarPenurunanJumlahKomplainBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            penurunanJumlahKomplainBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_gangguan_tahun_ini
              total_keluhan_tahun_ini
              total_gangguan_informasi_tahun_ini
              total_keluhan_informasi_tahun_ini
              total_informasi_tahun_ini
              total_tahun_ini
              total_gangguan_tahun_sebelumnya
              total_keluhan_tahun_sebelumnya
              total_gangguan_informasi_tahun_sebelumnya
              total_keluhan_informasi_tahun_sebelumnya
              total_informasi_tahun_sebelumnya
              total_tahun_sebelumnya
              delta_gangguan
              delta_keluhan
              delta_informasi
              persen_delta_gangguan
              persen_delta_keluhan
              persen_delta_informasi
              persen_delta_total
            }
          }
        `,
        agingComplaintBulanan: gql`
          query DaftarAgingComplaintBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            agingComplaintBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              avg_durasi_recovery_gangguan
              sla_gangguan
              avg_durasi_recovery_keluhan
              sla_keluhan
              aging_complaint_gangguan
              aging_complaint_keluhan
              avg_aging_complaint
            }
          }
        `,
        energyNotSalesBulanan: gql`
          query DaftarEnergyNotSalesBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            energyNotSalesBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              terencana
              tidak_terencana
              bencana_alam
              total
              kpi_ens
            }
          }
        `,
        kepatuhandanAkurasiDalamPelaporanBulanan: gql`
          query DaftarkepatuhandanAkurasiDalamPelaporanBulanan(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            kepatuhandanAkurasiDalamPelaporanBulanan(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              gangguan_berulang
              gangguan_total
              keluhan_berulang
              keluhan_total
              komplain_pelanggan
            }
          }
        `
      },
      kumulatif: {
        penurunanJumlahKomplainKumulatif: gql`
          query DaftarPenurunanJumlahKomplainKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            penurunanJumlahKomplainKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_gangguan_tahun_ini
              total_keluhan_tahun_ini
              total_gangguan_informasi_tahun_ini
              total_keluhan_informasi_tahun_ini
              total_informasi_tahun_ini
              total_tahun_ini
              total_gangguan_tahun_sebelumnya
              total_keluhan_tahun_sebelumnya
              total_gangguan_informasi_tahun_sebelumnya
              total_keluhan_informasi_tahun_sebelumnya
              total_informasi_tahun_sebelumnya
              total_tahun_sebelumnya
              delta_gangguan
              delta_keluhan
              delta_informasi
              persen_delta_gangguan
              persen_delta_keluhan
              persen_delta_informasi
              persen_delta_total
            }
          }
        `,
        agingComplaintKumulatif: gql`
          query DaftarAgingComplaintKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            agingComplaintKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              avg_durasi_recovery_gangguan
              sla_gangguan
              avg_durasi_recovery_keluhan
              sla_keluhan
              aging_complaint_gangguan
              aging_complaint_keluhan
              avg_aging_complaint
            }
          }
        `,
        energyNotSalesKumulatif: gql`
          query DaftarEnergyNotSalesKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            energyNotSalesKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              terencana
              tidak_terencana
              bencana_alam
              total
              kpi_ens
            }
          }
        `,
        kepatuhandanAkurasiDalamPelaporanKumulatif: gql`
          query DaftarkepatuhandanAkurasiDalamPelaporanKumulatif(
            #$regional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            kepatuhandanAkurasiDalamPelaporanKumulatif(
              #regional: $regional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              gangguan_berulang
              gangguan_total
              keluhan_berulang
              keluhan_total
              komplain_pelanggan
            }
          }
        `
      }
    }
  },
  cico: {
    laporanCheckInCheckOut: gql`
      query laporanCheckInCheckOut(
        $dateFrom: Date!
        $dateTo: Date!
        $idPosko: Int
        $idUid: Int
        $idUp3: Int
      ) {
        laporanCheckInCheckOut(
          dateFrom: $dateFrom
          dateTo: $dateTo
          idPosko: $idPosko
          idUid: $idUid
          idUp3: $idUp3
        ) {
          user_regu
          personil_yantek
          jumlah_wo_gangguan_individual
          avg_durasi_wo_gangguan_individual
          avg_rpt_wo_gangguan_individual
          avg_rct_wo_gangguan_individual
          jumlah_wo_penugasan_khusus
          avg_wo_penugasan_khusus
        }
      }
    `
  }
}
